pub enum PinPortStatement {
    Layer {
        layer_name: String,
        mask_num: Option<MaskNum>,
        spacing_or_width: Option<SpacingOrDesignRuleWidth>,
        rect: Rect<Coord>,
    },
    Polygon {
        layer_name: String,
        mask_num: Option<MaskNum>,
        spacing_or_width: Option<SpacingOrDesignRuleWidth>,
        polygon: SimplePolygon<Coord>,
    },
    Via {
        via_name: String,
        mask_num: Option<ViaMaskNum>,
        location: Point<Coord>,
    },
}
Definition of the shapes of a pin port.

Variants



Layer

Fields

layer_name: String

Name of the layer.

mask_num: Option<MaskNum>

Mask number.

spacing_or_width: Option<SpacingOrDesignRuleWidth>

SPACING: minimum spacing between other routing shapes an this pin. DESIGNRULEWIDTH: effective width of this pin used for calculating spacing.

rect: Rect<Coord>

Rectangular shape on this port.

Rectangular shape of the pin port.



Polygon

Fields

layer_name: String

Name of the layer.

mask_num: Option<MaskNum>

Mask number.

spacing_or_width: Option<SpacingOrDesignRuleWidth>

SPACING: minimum spacing between other routing shapes an this pin. DESIGNRULEWIDTH: effective width of this pin used for calculating spacing.

polygon: SimplePolygon<Coord>

Polygon shape on this port.

Polygon shape of the pin port.



Via

Fields

via_name: String

Name of the via.

mask_num: Option<ViaMaskNum>

Mask number.

location: Point<Coord>

Location of the via.

Via which is part of the pin port.