pub enum PlacementBlockageType {
Soft,
Partial(f64),
}Expand description
Specify the type of a soft blockage.
Variants
Soft
Initial placement shall not use the blocked area, but later stages can use it.
Partial(f64)
Give a maximal usage density for the initial placement in this area.
The density is given in percent and must have a value in the range [0.0, ..., 100.0].