pub enum RoutingPoint {
    Point {
        point: Point<Coord>,
        ext_value: Option<Coord>,
        mask_num: Option<MaskNum>,
    },
    Via {
        via_name: String,
        orient: Option<Orient>,
        via_mask_num: Option<ViaMaskNum>,
    },
    Rect {
        rect: Rect<Coord>,
        mask_num: Option<MaskNum>,
    },
    Virtual(Point<Coord>),
}
‘Vertex’ in the routing path.

Variants



Point

Fields

point: Point<Coord>

Location of the path vertex.

ext_value: Option<Coord>

Extension of the wire past the endpoint. Default is half the wire width.

mask_num: Option<MaskNum>

Mask-number of the following path segment.

A simple vertex of a path.



Via

Fields

via_name: String

Name of the via to be used.

orient: Option<Orient>

Rotation of the via.

via_mask_num: Option<ViaMaskNum>

Mask-number of the via geometries.

A via, placed at the location of the last path vertex.



Rect

Fields

rect: Rect<Coord>

Rectangle. Absolute coordinates. DEF stores coordinates relative to the last path point, but here the coordinates are already resolved.

mask_num: Option<MaskNum>

Mask-number of the rectangle.

A rectangular shape with absolute coordinates.



Virtual(Point<Coord>)

A ‘virtual’ path vertex. The path segment leading to the virtual vertex is not materialized. This is equal to ending the path at the last point and starting a new path at the virtual vertex, hence allows to create discontinuous paths.