Enum libreda_lefdef::def_ast::ViaDefinition
source · pub enum ViaDefinition {
ViaGeometry(Vec<ViaGeometry>),
ViaRule,
}Expand description
Definition of via geometries or rules to generate a via.
Variants
ViaGeometry(Vec<ViaGeometry>)
Explicit definition of the via by a set of geometrical shapes.
ViaRule
Implicit definition by design rules for the via.