pub struct Component {
    pub name: String,
    pub model_name: String,
    pub eeq_master: Option<String>,
    pub source: ComponentSource,
    pub position: Option<(Point<i32>, Orient, bool)>,
    pub halo: Option<(bool, i32, i32, i32, i32)>,
    pub route_halo: Option<(i32, String, String)>,
    pub weight: u32,
    pub region: Option<String>,
    pub properties: BTreeMap<String, PropertyValue>,
}
Instantiation of a component in DEF.

Fields

name: String

Name of the component instance.

model_name: String

Name of the component template/model.

eeq_master: Option<String>

Name of the electrically equivalent master.

source: ComponentSource

Tells where this component has been created.

position: Option<(Point<i32>, Orient, bool)>

Placement location of the component. (location, orientation, is fixed)

halo: Option<(bool, i32, i32, i32, i32)>

Placement halo. Defines a placement blockage around the component. If is_soft is set, then the blockage does not need to be respected after the initial placement. (is_soft, left, bottom, right, top).

route_halo: Option<(i32, String, String)>

Routing halo. TODO. Structure is (haloDist, minLayer, maxLayer).

weight: u32

Weight of the component placement. Tells how costly a relocation of the component is.

region: Option<String>

Name of the region where this component should be placed.

properties: BTreeMap<String, PropertyValue>

Custom properties.