Struct libreda_lefdef::def_ast::Group
source · pub struct Group {
pub component_names: Vec<String>,
pub region_name: Option<String>,
pub properties: BTreeMap<String, PropertyValue>,
}Expand description
Define a group of components. Optionally restrict the component locations to a region.
Fields
component_names: Vec<String>Names or name patterns of the components that belong to this group.
region_name: Option<String>Name of the region in which the group must lie. Region restrictions defined by the component overwrite the restrictions defined by its group.
properties: BTreeMap<String, PropertyValue>User defined properties.