pub struct LayerBlockage {
    pub layer: String,
    pub slots: bool,
    pub fills: bool,
    pub pushdown: bool,
    pub except_pg_net: bool,
    pub component: Option<String>,
    pub spacing: Option<Coord>,
    pub spacing_or_designrule_width: Option<SpacingOrDesignRuleWidth>,
    pub mask_num: Option<MaskNum>,
    pub blockage_shapes: Vec<RectOrPolygon>,
}
Define a region on a layer that is blocked from being used.

Fields

layer: String

Layer of the blockage.

slots: bool

Block insertion of slots.

fills: bool

Block insertion of metal fills.

pushdown: bool

TBD

except_pg_net: bool

Blockage does not concern power and ground nets, only signals.

component: Option<String>

TBD

spacing: Option<Coord>

TBD

spacing_or_designrule_width: Option<SpacingOrDesignRuleWidth>

Either minimal allowed spacing or an effective width.

mask_num: Option<MaskNum>

Mask number.

blockage_shapes: Vec<RectOrPolygon>

Geometry of the blockage area.