Struct libreda_lefdef::def_ast::Region
source · pub struct Region {
pub regions: Vec<Rect<Coord>>,
pub region_type: Option<RegionType>,
pub properties: (),
}Expand description
Defines a physical area that can be used to place components or groups.
Fields
regions: Vec<Rect<Coord>>Physical region defined as a set of rectangles.
region_type: Option<RegionType>Type of the region constraint. Default: Assigned cells are placed in the region. Other cells can be placed in the region as well.
properties: ()Properties of the region.