Struct libreda_lefdef::def_ast::Tracks
source · pub struct Tracks {
pub is_horizontal: bool,
pub start: Coord,
pub num_tracks: u32,
pub step: Coord,
pub mask: Option<(MaskNum, bool)>,
pub layers: Vec<String>,
}Expand description
Definition routing tracks as a grid of equally spaced lines.
Fields
is_horizontal: boolDirection of the track. Can be horizontal when ‘Y’ is defined in DEF (true) or vertical with ‘X’ in DEF (false).
start: CoordDistance of the track line to the origin. For horizontal tracks this is the vertical offset (y coordinate), for vertical tracks this is the horizontal offset (y coordinate).
num_tracks: u32Number of tracks for the grid. Must be larger than 0.
step: CoordSpacing between tracks.
mask: Option<(MaskNum, bool)>An optional tuple ( mask number, SAMEMASK ).
mask number: Mask of the first track as used for double or triple patterning.
Usually the mask is cycled for all subsequent tracks.
SAMEMASK: Use the same mask number for all tracks.
layers: Vec<String>Routing layers to be used for this track. Possibly more than one.