struct LEFDEF<'a> {
    lef: &'a LEF,
    def: &'a DEF,
    components_by_name: HashMap<&'a str, &'a Component>,
    macro_references: HashMap<&'a str, Vec<&'a Component>>,
}
Fused LEF and DEF structure. Holds only references to LEF and DEF structs but creates indices for faster name lookup of components.

This data structure implements the HierarchyBase, NetlistBase and LayoutBase view traits.

Fields

lef: &'a LEF

Underlying LEF struct.

def: &'a DEF

Underlying DEF struct.

components_by_name: HashMap<&'a str, &'a Component>

Index for finding components by name.

macro_references: HashMap<&'a str, Vec<&'a Component>>

For each macro name a list of components that instantiate this macro.

Implementations

source

impl<'a> LEFDEF<'a>

source

pub fn new(lef: &'a LEF, def: &'a DEF) -> Self

Create a new fused LEF/DEF structure from a LEF and DEF struct.

source

fn top_cell_name(&self) -> &str

source

fn top_cell(&self) -> CellId

source

pub fn def(&self) -> &DEF

Access the underlying DEF struct.

source

pub fn lef(&self) -> &LEF

Access the underlying LEF struct.

source

fn component_by_name(&self, name: &str) -> Option<&Component>

Find a component by its name using the lookup table.