Enum libreda_lefdef::LefDefParseError
source · pub enum LefDefParseError {
ParserError(ParserError<char>),
InvalidCharacter,
UnexpectedEndOfFile,
UnexpectedToken(String, String),
UnknownToken(String),
InvalidLiteral(String),
IllegalBusBitChars(char, char),
NotImplemented(&'static str),
UndefinedProperty(String),
ParseIntError(ParseIntError),
Other(&'static str),
}Expand description
Error while parsing LEF or DEF. TODO: Separate lexer errors from LEF/DEF specific errors.
Variants
ParserError(ParserError<char>)
Error during parsing.
InvalidCharacter
Encountered invalid character.
UnexpectedEndOfFile
Reached end of file before end of library arrived.
UnexpectedToken(String, String)
Expected and actual token.
UnknownToken(String)
Unknown token. The token is given as a string.
InvalidLiteral(String)
Unknown literal. The literal is given as a string.
IllegalBusBitChars(char, char)
Illegal value for bus bit chars.
NotImplemented(&'static str)
Something is not yet implemented.
UndefinedProperty(String)
Using a property name that has not been defined in PROPERTYDEFINITIONS.
ParseIntError(ParseIntError)
Failed to parse an integer.
Other(&'static str)
Some other error defined by a string.