pub enum Layer {
    MasterSlice(MasterSliceLayer),
    Cut(CutLayer),
    Routing(RoutingLayer),
}
Layer definition. A layer can have different types:

  • MasterSlice: This is usually the first layer in the stack.
  • Cut: Via layer that connects the previous and next layer.
  • Routing: Metal wires.

Variants



MasterSlice(MasterSliceLayer)

MASTERSLICE (poly) layer.



Cut(CutLayer)

CUT layer.



Routing(RoutingLayer)

ROUTING layer.

Implementations

source

impl Layer

source

pub fn name(&self) -> &String

Get the name of the layer.