pub enum SpacingOrDesignRuleWidth {
MinSpacing(f64),
DesignRuleWidth(f64),
}Expand description
Holds either the value of the SPACING argument or DESIGNRULEWIDTH argument of a geometrical layer as used in the LAYER definition in PIN or OBS.
Variants
MinSpacing(f64)
Minimal allowed spacing between this shape and other shapes.
DesignRuleWidth(f64)
Effective design rule width.