Struct libreda_lefdef::lef_ast::CutSpacingRule
source · pub struct CutSpacingRule {
pub spacing: f64,
pub center_to_center: bool,
pub same_net: bool,
}Expand description
SPACING rules for a CUT (via) layer.
Fields
spacing: f64Spacing between cuts.
center_to_center: boolMeasure the spacing from center of the cut to the center of another cut instead of from edge to edge. This is enabled by default.
same_net: boolTell if this spacing rule applies for same-net cuts.