pub struct EnclosureRule {
    pub above: bool,
    pub below: bool,
    pub overhang1: f64,
    pub overhang2: f64,
    pub min_width: f64,
    pub except_extracut_within: f64,
    pub min_length: f64,
}
ENCLOSURE rules for a CUT (via) layer.

Fields

above: bool

Rule applies for the routing layer above.

below: bool

Rule applies for the routing layer below.

overhang1: f64

Adjacent routing layers must overhang on the two opposing sides (in x-direction (?)).

overhang2: f64

Adjacent routing layers must overhang on the two opposing sides (in y-direction (?)).

min_width: f64

Rule only applies if the width of the adjacent shape of the routing layer is greater or equal than min_width. Default is 0.

except_extracut_within: f64

TODO Don’t use the WIDTH rule when another via is present to the current via within this distance.

min_length: f64

Rule only applies if the total length of the longest overhangs is greater or equal to min_length. The overhang length is measured from the via cut center. Default is 0.