Struct libreda_lefdef::lef_ast::LayerGeometries
source · pub struct LayerGeometries {
pub layer_name: String,
pub except_pg_net: bool,
pub spacing_or_designrule_width: Option<SpacingOrDesignRuleWidth>,
pub width: Option<f64>,
pub geometries: Vec<Geometry>,
pub vias: Vec<()>,
}Expand description
Geometrical shapes on a named layer as used in MACRO PIN and OBS definitions.
Fields
layer_name: StringName of the layer.
except_pg_net: boolObstruction blocks signal routing but not power or ground routing.
spacing_or_designrule_width: Option<SpacingOrDesignRuleWidth>Either minimal allowed spacing or an effective width.
width: Option<f64>Specify the width to be used for PATH. If not specified the default with for this layer is used.
geometries: Vec<Geometry>Geometrical shapes (PATH, RECT, POLYGON). Together with a repetition pattern.
vias: Vec<()>Specify vias to be placed with their locations.