Struct libreda_lefdef::lef_ast::MacroPin
source · pub struct MacroPin {
pub name: String,
pub taper_rule: Option<String>,
pub direction: Option<PinDirection>,
pub signal_use: Option<SignalUse>,
pub supply_sensitivity: Option<String>,
pub ground_sensitivity: Option<String>,
pub shape_type: Option<PinShape>,
pub must_join: Option<String>,
pub ports: Vec<MacroPinPort>,
}Expand description
PIN definition of a MACRO.
Fields
name: StringName of the pin.
taper_rule: Option<String>Name of the NONDEFAULTRULE to be used when tapering wires to this pin.
direction: Option<PinDirection>Signal direction.
signal_use: Option<SignalUse>Type of the signal for this pin.
supply_sensitivity: Option<String>Net name where this pin should be connected if it is tied HIGH (constant logical 1).
ground_sensitivity: Option<String>Net name where this pin should be connected if it is tied LOW (constant logical 0).
shape_type: Option<PinShape>Specify special connection requirements of the pin.
must_join: Option<String>Name of another pin that must be connected to this pin.
ports: Vec<MacroPinPort>