Struct libreda_lefdef::lef_ast::SiteDefinition
source · pub struct SiteDefinition {
pub name: String,
pub size: (f64, f64),
pub symmetry: Symmetry,
pub class: SiteClass,
pub row_pattern: Vec<(String, Orient)>,
}Expand description
SITE definition.
Fields
name: StringName of the site.
size: (f64, f64)Dimensions of the site.
symmetry: SymmetryDefine orientations of the site that are considered equivalent. This is used for example to specify whether cell flipping inside a row is allowed.
class: SiteClassSpecify site type (IO or CORE).
row_pattern: Vec<(String, Orient)>Construct this site as a composition of previously defined sites. List of tuples: (previous site, orientation)