pub struct LEFDesignRuleAdapter<'a, L: LayoutBase> {
    lef: &'a LEF,
    dbu: f64,
    layer_mapping: HashMap<L::LayerId, &'a Layer>,
    layer_stack: Vec<(L::LayerId, &'a Layer)>,
    ty: PhantomData<L>,
}
Provides standardized read access to the design-rules defined in a LEF structure.

Fields

lef: &'a LEF

Underlying LEF data.

dbu: f64

Data-base units per micron.

layer_mapping: HashMap<L::LayerId, &'a Layer>

Mapping from layer IDs to actual LEF layer data.

layer_stack: Vec<(L::LayerId, &'a Layer)>

Layers sorted by the processing order: Starts with layers close to the substrate, ends with top level metal layers.

ty: PhantomData<L>

Implementations

source

impl<'a, L> LEFDesignRuleAdapter<'a, L>where L: LayoutBase, L::Coord: ToPrimitive,

source

fn db_distance_to_lef(&self, db_distance: L::Coord) -> f64

Convert from a distance in data-base units into a LEF distance (f64).

source

impl<'a, L> LEFDesignRuleAdapter<'a, L>where L: LayoutBase, L::Coord: FromPrimitive,

source

fn lef_distance_to_db(&self, lef_distance: f64) -> L::Coord

Convert from a LEF distance (f64) into the correct unit used by the layout.

source

impl<'a, L> LEFDesignRuleAdapter<'a, L>where L: LayoutBase, L::Coord: FromPrimitive + ToPrimitive,

source

pub fn new(lef: &'a LEF, layout: &L) -> Self

Create a new design rule adapter for a LEF data structure. Derives the mapping from layer IDs and LEF layers based on the layer names.

source

pub fn new_from_layer_mapping( lef: &'a LEF, layer_ids_by_name: &HashMap<String, L::LayerId>, dbu: f64 ) -> Self

Create a new design rule adapter for a LEF data structure with a custom mapping between layer names and layer IDs.

source

fn extract_layer_mapping_from_layout(layout: &L) -> HashMap<String, L::LayerId>

Find the mapping from layer names to layer IDs.

source

fn create_layer_mapping( &mut self, layer_ids_by_name: &HashMap<String, L::LayerId> )

Initialize the mapping: layer ID -> LEF layer structure.