pub struct LEFDesignRuleAdapter<'a, L: LayoutBase> { /* private fields */ }
Provides standardized read access to the design-rules defined in a LEF structure.

Implementations

Create a new design rule adapter for a LEF data structure. Derives the mapping from layer IDs and LEF layers based on the layer names.

Create a new design rule adapter for a LEF data structure with a custom mapping between layer names and layer IDs.