Enum libreda_lefdef::def_ast::ComponentSource
source · pub enum ComponentSource {
Netlist,
Dist,
User,
Timing,
}Expand description
Source of a component.
Variants
Netlist
Component comes from the original netlist. This is the default value.
Dist
Physical component that connects only to power and ground nets. (Filler cells, well-taps, decoupling capacitors).
User
Component generated by the user for some other reason.
Timing
Component was inserted to meet timing constraints.