Enum libreda_lefdef::def_ast::NetSource
source · pub enum NetSource {
Dist,
Netlist,
Test,
Timing,
User,
}Expand description
Source of a net.
Variants
Dist
Physical component that connects only to power and ground nets. (Filler cells, well-taps, decoupling capacitors).
Netlist
Physical component that connects only to power and ground nets. (Filler cells, well-taps, decoupling capacitors).
Test
Net belongs to a scan-chain.
Timing
Component was inserted to meet timing constraints.
User
Component generated by the user for some other reason.