Enum libreda_lefdef::def_ast::PinPortStatement
source · pub enum PinPortStatement {
Layer {
layer_name: String,
mask_num: Option<MaskNum>,
spacing_or_width: Option<SpacingOrDesignRuleWidth>,
rect: Rect<Coord>,
},
Polygon {
layer_name: String,
mask_num: Option<MaskNum>,
spacing_or_width: Option<SpacingOrDesignRuleWidth>,
polygon: SimplePolygon<Coord>,
},
Via {
via_name: String,
mask_num: Option<ViaMaskNum>,
location: Point<Coord>,
},
}Expand description
Definition of the shapes of a pin port.
Variants
Layer
Rectangular shape of the pin port.
Fields

spacing_or_width: Option<SpacingOrDesignRuleWidth>SPACING: minimum spacing between other routing shapes an this pin. DESIGNRULEWIDTH: effective width of this pin used for calculating spacing.
Polygon
Polygon shape of the pin port.
Fields

spacing_or_width: Option<SpacingOrDesignRuleWidth>SPACING: minimum spacing between other routing shapes an this pin. DESIGNRULEWIDTH: effective width of this pin used for calculating spacing.

polygon: SimplePolygon<Coord>Polygon shape on this port.
Via
Via which is part of the pin port.