Enum libreda_lefdef::def_ast::RegionType
source · pub enum RegionType {
Fence,
Guide,
}Expand description
Type of the region. A region defines a physical are where components should be placed. Fence regions force components to be placed inside, guides are not hard constraints.
Variants
Fence
Hard constraint. Only components assigned to this region are allowed to be placed here.
Guide
Soft constraint (can be violated if necessary).