Enum libreda_lefdef::def_ast::RoutingPoint
source · pub enum RoutingPoint {
Point {
point: Point<Coord>,
ext_value: Option<Coord>,
mask_num: Option<MaskNum>,
},
Via {
via_name: String,
orient: Option<Orient>,
via_mask_num: Option<ViaMaskNum>,
},
Rect {
rect: Rect<Coord>,
mask_num: Option<MaskNum>,
},
Virtual(Point<Coord>),
}Expand description
‘Vertex’ in the routing path.
Variants
Point
Fields
A simple vertex of a path.
Via
Fields

via_mask_num: Option<ViaMaskNum>Mask-number of the via geometries.
A via, placed at the location of the last path vertex.
Rect
Fields
A rectangular shape with absolute coordinates.
Virtual(Point<Coord>)
A ‘virtual’ path vertex. The path segment leading to the virtual vertex is not materialized. This is equal to ending the path at the last point and starting a new path at the virtual vertex, hence allows to create discontinuous paths.