Enum libreda_lefdef::def_ast::WiringClass
source · pub enum WiringClass {
COVER,
FIXED,
ROUTED,
NOSHIELD,
}Expand description
Wiring class. Tells whether a wiring can be changed by tools, manually or not at all.
Variants
COVER
Route cannot be changed at all.
FIXED
Route cannot be changed by automatic tools, only by interactive commands.
ROUTED
Route can be changed by automatic tool. A net that is routed must also specify the layer name.
NOSHIELD
Last wide segment is not shielded.