Struct libreda_lefdef::def_ast::Net
source · pub struct Net {Show 18 fields
pub name: Option<String>,
pub mustjoin: Option<Mustjoin>,
pub terminals: Vec<NetTerminal>,
pub shield_nets: Vec<String>,
vpin: BTreeMap<String, ()>,
subnets: BTreeMap<String, ()>,
pub xtalk_class: u16,
pub non_default_rule: Option<String>,
pub regular_wiring: Vec<RegularWiring>,
pub source: NetSource,
pub fixed_bump: bool,
pub frequency: Option<f64>,
pub original: Option<String>,
pub net_use: DEFSignalUse,
pub pattern: NetPattern,
pub est_cap: Option<f64>,
pub weight: u32,
pub properties: BTreeMap<String, PropertyValue>,
}Expand description
Definition of a net and possibly its routes.
Fields
name: Option<String>Name of the net. Must be generated for MUSTJOIN nets. ‘MUSTJOIN’ is an invalid net name.
mustjoin: Option<Mustjoin>Net name is generated for MUSTJOIN nets.
terminals: Vec<NetTerminal>Terminals connected to the net.
shield_nets: Vec<String>Names of special nets that are used to shield this net. The shield nets must be defined earlier in ‘SPECIALNETS’.
vpin: BTreeMap<String, ()>subnets: BTreeMap<String, ()>xtalk_class: u16Crosstalk class number.
Default is 0 which will not be written to DEF.
Should be a value from 0 to 200.
non_default_rule: Option<String>Use another width rule than the default rule defined in the LEF WIDTH statement for the routing layer.
regular_wiring: Vec<RegularWiring>Specify the physical wiring.
source: NetSourceSource from where the net was created.
fixed_bump: boolFixed bump: TBD
frequency: Option<f64>Frequency of the net. Used as a hint for the router.
original: Option<String>If this net results from partitioning another net, then this refers to the original net.
net_use: DEFSignalUseUsage type of the net.
pattern: NetPatternDesired routing pattern for the net.
est_cap: Option<f64>Estimated wire capacitance of this net.
weight: u32Weight of the net. Nets with high weight should be tried to keep short by routing tools. Default = 1.
properties: BTreeMap<String, PropertyValue>Additional properties.