Struct libreda_lefdef::def_ast::Pin
source · pub struct Pin {
pub pin_name: String,
pub net_name: String,
pub special: bool,
pub direction: Option<PinDirection>,
pub net_expr: Option<String>,
pub supply_sensitivity: Option<String>,
pub ground_sensitivity: Option<String>,
pub signal_use: DEFSignalUse,
pub antenna_rules: (),
pub ports: Vec<PinPort>,
}Expand description
External pin definition in DEF. Associates an external pin name with the internal net name.
Fields
pin_name: StringName of the external pin.
net_name: StringName of the internal net.
special: boolMark the pin as ‘special’. Special pins are to be routed with a special router with special wiring.
direction: Option<PinDirection>Signal direction of the pin. Typically this is specified in the timing library, not in DEF.
net_expr: Option<String>TBD
supply_sensitivity: Option<String>Net name where this pin should be connected if it is tied HIGH (constant logical 1).
ground_sensitivity: Option<String>Net name where this pin should be connected if it is tied LOW (constant logical 0).
signal_use: DEFSignalUseType of the signal for this pin. Default is ‘SIGNAL’.
antenna_rules: ()Anntenna rules. TODO
ports: Vec<PinPort>Definitions of physical shapes of the pin.