Struct libreda_lefdef::def_ast::RowStepPattern
source · pub struct RowStepPattern {
pub num_x: u32,
pub num_y: u32,
pub step: Option<(Coord, Coord)>,
}Expand description
Repetition pattern for rows.
Fields
num_x: u32Number of repetitions in x-direction. At least one of num_x or num_y must be 1.
num_y: u32Number of repetitions in y-direction. At least one of num_x or num_y must be 1.
step: Option<(Coord, Coord)>Step size for x and y direction. By default the step size equals the size of the referenced site such that sites are arranged without overlap nor gap between.