Struct libreda_lefdef::def_impl::LEFDEF
source · struct LEFDEF<'a> {
lef: &'a LEF,
def: &'a DEF,
components_by_name: HashMap<&'a str, &'a Component>,
macro_references: HashMap<&'a str, Vec<&'a Component>>,
}Expand description
Fused LEF and DEF structure. Holds only references to LEF and DEF structs but creates indices for faster name lookup of components.
This data structure implements the HierarchyBase, NetlistBase and LayoutBase view traits.
Fields
lef: &'a LEFUnderlying LEF struct.
def: &'a DEFUnderlying DEF struct.
components_by_name: HashMap<&'a str, &'a Component>Index for finding components by name.
macro_references: HashMap<&'a str, Vec<&'a Component>>For each macro name a list of components that instantiate this macro.
Implementations
sourceimpl<'a> LEFDEF<'a>
impl<'a> LEFDEF<'a>
sourcepub fn new(lef: &'a LEF, def: &'a DEF) -> Self
pub fn new(lef: &'a LEF, def: &'a DEF) -> Self
Create a new fused LEF/DEF structure from a LEF and DEF struct.
fn top_cell_name(&self) -> &str
fn top_cell(&self) -> CellId
sourcefn component_by_name(&self, name: &str) -> Option<&Component>
fn component_by_name(&self, name: &str) -> Option<&Component>
Find a component by its name using the lookup table.