Function libreda_lefdef::def_parser::read_def_property
source · pub fn read_def_property<I>(
property_definitions: &mut BTreeMap<String, DEFPropertyDefinition>,
tk: &mut Tokenized<I, LefDefLexer>
) -> Result<Option<(String, PropertyValue)>, LefDefParseError>where
I: Iterator<Item = char> + PeekingNext,Expand description
Read a property name and a property value. Checks if the property is specified in the PROPERTYDEFINITIONS. If not, an error is returned and the property should be ignored.
Returns (property_name, value).