Enum libreda_lefdef::import::LefDefImportError
source · pub enum LefDefImportError {
ComponentModelNotFound {
component_name: String,
model_name: String,
},
ComponentNotFound(String),
ViaNotFound(String),
LayerNotFound(String),
CellNameAlreadyExists(String),
Other(String),
}Expand description
Error type returned from LEF/DEF input and output functions.
Variants
ComponentModelNotFound
The model (aka template or cell type) of a component instance was not found.
Fields
ComponentNotFound(String)
A component was referenced by name but not found.
ViaNotFound(String)
A via is referenced by name but cannot be found.
LayerNotFound(String)
The layer could not be found in the target design and the creation of new layers is disabled.
CellNameAlreadyExists(String)
Cell of this name is already present in the layout and now being redefined in during the import.
Other(String)
Unspecified error.