Struct libreda_lefdef::lef_ast::CutLayer
source · pub struct CutLayer {
pub name: String,
pub mask_num: Option<u32>,
pub spacing: Vec<CutSpacingRule>,
pub spacing_table: Option<()>,
pub array_spacing: Option<()>,
pub width: Option<f64>,
pub enclosure: Vec<EnclosureRule>,
pub prefer_enclosure: Vec<EnclosureRule>,
pub resistance: Option<f64>,
pub properties: BTreeMap<String, PropertyValue>,
}Expand description
Design rules for a CUT (via) layer.
Fields
name: StringName of the cut layer.
mask_num: Option<u32>Number of masks used for double- or triple-patterning.
spacing: Vec<CutSpacingRule>Minimum spacing rules between cuts of same or different nets.
spacing_table: Option<()>Spacing table to be used on this cut layer.
array_spacing: Option<()>TODO
width: Option<f64>Minimum width of a cut in microns. Usually this is the only allowed size of a cut.
enclosure: Vec<EnclosureRule>Enclosure rules that must be met.
prefer_enclosure: Vec<EnclosureRule>Preferred enclosure rules that can be used to improve yield but must not necessarily be met.
resistance: Option<f64>Resistance per cut.
properties: BTreeMap<String, PropertyValue>Custom properties.