Struct libreda_lefdef::lef_ast::GeneratedVia
source · pub struct GeneratedVia {
pub is_default: bool,
pub rule_name: String,
pub cut_size: (f64, f64),
pub layers: (String, String, String),
pub cut_spacing: (f64, f64),
pub enclosure: (f64, f64, f64, f64),
pub num_rows_cols: Option<(u32, u32)>,
pub origin: Option<(f64, f64)>,
pub offset: Option<(f64, f64, f64, f64)>,
pub cut_pattern: Option<String>,
}Expand description
A generated via.
Fields
is_default: boolDefault via to be used for routing between the adjacent layers.
rule_name: StringVia generate rule which was used to generate this via.
cut_size: (f64, f64)Width and height of the via cut.
layers: (String, String, String)Bottom, cut and top layer.
cut_spacing: (f64, f64)Spacing in x and y directions.
enclosure: (f64, f64, f64, f64)bottom-x, bottom-y, top-x, top-y enclosure
num_rows_cols: Option<(u32, u32)>Number of rows and columns.
origin: Option<(f64, f64)>Coordinate of the origin.
offset: Option<(f64, f64, f64, f64)>Offsets of bottom-x, bottom-y, top-x, top-y
cut_pattern: Option<String>ASCII string which encodes the pattern of repeated vias.