Struct libreda_lefdef::lef_ast::StepPattern
source · pub struct StepPattern {
pub num_x: u64,
pub num_y: u64,
pub space_x: f64,
pub space_y: f64,
}Expand description
Array-like repetition of an element.
Use each_offset() to iterate through all offsets described by this pattern.
Fields
num_x: u64Number of repetitions in x-direction.
num_y: u64Number of repetitions in y-direction.
space_x: f64Spacing in x-direction.
space_y: f64Spacing in y-direction.
Implementations
sourceimpl StepPattern
impl StepPattern
sourcepub fn each_offset(&self) -> impl Iterator<Item = (f64, f64)> + '_
pub fn each_offset(&self) -> impl Iterator<Item = (f64, f64)> + '_
Return an iterator over each offset of the step pattern. The origin is at (0.0, 0.0).