Struct libreda_lefdef::lef_ast::TechnologyLef
source · pub struct TechnologyLef {
pub units: Units,
pub manufacturing_grid: Option<f64>,
pub use_min_spacing: Option<()>,
pub clearance_measure: ClearanceMeasure,
pub property_definitions: BTreeMap<String, ()>,
pub fixed_mask: bool,
pub layers: Vec<Layer>,
pub max_via_stack: Option<(u64, Option<(String, String)>)>,
pub via_rules_generate: BTreeMap<String, ()>,
pub non_default_rule: (),
}Expand description
Technology LEF containing technology information.
Fields
units: UnitsUnits used in this library.
manufacturing_grid: Option<f64>Grid for geometrical alignment. Cells and shapes snap to locations on this grid.
use_min_spacing: Option<()>clearance_measure: ClearanceMeasureType of distance measure (Euclidean: dx^2 + dy^2, MaxXY: max(dx, dy))
property_definitions: BTreeMap<String, ()>Definitions of custom properties.
fixed_mask: boolDisable shifting of masks. When set, shifting of macro pin mask assignments to other masks is not allowed. Used for technologies that use multi-mask patterning.
layers: Vec<Layer>Layer definitions (masterslice, cut, routing, …). Layers are defined in their process order from bottom to top.
max_via_stack: Option<(u64, Option<(String, String)>)>Maximum number of single-cut vias stacked on top of each other. Optionally defines a range of (bottom layer, top layer) where the rule applies. Otherwise the rule applies to all layers.
via_rules_generate: BTreeMap<String, ()>VIA GENERATE rules by name.
non_default_rule: ()NONDEFAULTRULEs by name.